function root = extension_root(ext)

% extension_root - root directory of extension
% --------------------------------------------
%
% root = extension_root(ext)
%
% Input:
% ------
%  ext - extension
%
% Output:
% -------
%  root - extension root

%--------------------------------
% Author: Harold Figueroa
%--------------------------------
% $Revision: 1600 $
% $Date: 2005-08-18 17:41:06 -0400 (Thu, 18 Aug 2005) $
%--------------------------------

% TODO: extend to consider when we may have more than one extension root

root = [extensions_root, filesep, type_to_dir(ext.subtype), filesep, ext.name];
